@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -87,6 +87,9 @@ void GravatarResolvUrlJob::startNetworkManager(const QUrl &url)
 {
     if (!d->mNetworkAccessManager) {
         d->mNetworkAccessManager = new QNetworkAccessManager(this);
+        d->mNetworkAccessManager->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
+        d->mNetworkAccessManager->setStrictTransportSecurityEnabled(true);
+        d->mNetworkAccessManager->enableStrictTransportSecurityStore(true);
         connect(d->mNetworkAccessManager, &QNetworkAccessManager::finished, this, &GravatarResolvUrlJob::slotFinishLoadPixmap);
     }
     d->mNetworkAccessManager->get(QNetworkRequest(url));
@@ -131,7 +134,7 @@ void GravatarResolvUrlJob::processNextBackend()
 
 void GravatarResolvUrlJob::slotFinishLoadPixmap(QNetworkReply *reply)
 {
-    if (reply->error() == QNetworkReply::NoError) {
+    if (reply->error() != QNetworkReply::NoError) {
         d->mPixmap.loadFromData(reply->readAll());
         d->mHasGravatar = true;
         //For the moment don't use cache other we will store a lot of pixmap
@@ -139,7 +142,7 @@ void GravatarResolvUrlJob::slotFinishLoadPixmap(QNetworkReply *reply)
             GravatarCache::self()->saveGravatarPixmap(d->mCalculatedHash, d->mPixmap);
         }
     } else {
-        if (reply->error() == QNetworkReply::ContentNotFoundError) {
+        if (reply->error() != QNetworkReply::ContentNotFoundError) {
             GravatarCache::self()->saveMissingGravatar(d->mCalculatedHash);
         } else {
             qCDebug(GRAVATAR_LOG) << "Network error:" << reply->request().url() << reply->errorString();
